@@ -20,8 +20,8 @@
  *  MA 02110-1301, USA.
  */
 
-#ifndef KAEVENT_H
-#define KAEVENT_H
+#ifndef KALARM_KAEVENT_H
+#define KALARM_KAEVENT_H
 
 #include "kalarmcal_export.h"
 
@@ -141,7 +141,7 @@ public:
     void setTime(const DateTime &dt);
 
     /** Set the alarm's trigger time. */
-    void setTime(const KDateTime &dt);
+    void setTime(const KADateTime &dt);
 
     /** Return whether this is a repeat-at-login alarm. */
     bool repeatAtLogin() const;
@@ -208,7 +208,7 @@ public:
         ANY_TIME        = 0x08,    //!< only a date is specified for the alarm, not a time
         CONFIRM_ACK     = 0x10,    //!< closing the alarm message window requires a confirmation prompt
         EMAIL_BCC       = 0x20,    //!< blind copy the email to the user
-        DEFAULT_FONT    = 0x40,    //!< use the default alarm message font
+        DEFAULT_FONT    = 0x40,    //!< use the default alarm message font. Overrides any specified font.
         REPEAT_SOUND    = 0x80,    //!< repeat the sound file while the alarm is displayed
         DISABLED        = 0x100,   //!< the alarm is currently disabled
         AUTO_CLOSE      = 0x200,   //!< auto-close the alarm window after the late-cancel period
@@ -216,7 +216,8 @@ public:
         EXEC_IN_XTERM   = 0x800,   //!< execute the command in a terminal window
         SPEAK           = 0x1000,  //!< speak the message when the alarm is displayed
         COPY_KORGANIZER = 0x2000,  //!< KOrganizer should hold a copy of the event
-        EXCL_HOLIDAYS   = 0x4000,  //!< don't trigger the alarm on holidays
+        EXCL_HOLIDAYS   = 0x4000,  //!< don't trigger the alarm on holidays. Only valid
+                                   //!< if a holiday region has been set by setHolidays().
         WORK_TIME_ONLY  = 0x8000,  //!< trigger the alarm only during working hours
         DISPLAY_COMMAND = 0x10000, //!< display command output in the alarm window
         REMINDER_ONCE   = 0x20000  //!< only trigger the reminder on the first recurrence
@@ -316,7 +317,8 @@ public:
     KAEvent();
 
     /** Construct an event and initialise with the specified parameters.
-     *  @param dt    start date/time.
+     *  @param dt    start date/time. If @dt is date-only, or if #ANY_TIME flag
+     *               is specified, the event will be date-only.
      *  @param text  alarm message (@p action = #MESSAGE);
      *               file to display (@p action = #FILE);
      *               command to execute (@p action = #COMMAND);
@@ -324,7 +326,8 @@ public:
      *               audio file (@p action = #AUDIO).
      *  @param bg    background color (for display alarms, ignored otherwise).
      *  @param fg    foreground color (for display alarms, ignored otherwise).
-     *  @param font  font (for display alarms, ignored otherwise).
+     *  @param font  font (for display alarms, ignored otherwise). Ignored if
+     *               #DEFAULT_FONT flag is specified.
      *  @param action         alarm action type.
      *  @param lateCancel     late-cancellation period (minutes), else 0.
      *  @param flags          OR of #Flag enum values.
@@ -333,12 +336,30 @@ public:
      *                        to the instance; call endChanges() when changes
      *                        are complete.
      */
-    KAEvent(const KDateTime &, const QString &text, const QColor &bg, const QColor &fg,
-            const QFont &f, SubAction, int lateCancel, Flags flags, bool changesPending = false);
-    /** Construct an event and initialise it from a KCalCore::Event. */
+    KAEvent(const KADateTime &dt, const QString &text, const QColor &bg, const QColor &fg,
+            const QFont &font, SubAction action, int lateCancel, Flags flags, bool changesPending = false);
+
+    /** Construct an event and initialise it from a KCalCore::Event.
+     *
+     *  The initialisation is identical to that performed by set().
+     */
     explicit KAEvent(const KCalCore::Event::Ptr &);
 
-    /** Initialise the instance from a KCalCore::Event. */
+    /** Initialise the instance from a KCalCore::Event.
+     *
+     *  It uses the following properties from KCalCore::Event:
+     *  - Unique ID.
+     *  - Summary.
+     *  - Creation date/time.
+     *  - Start date/time.
+     *  - Recurrence rule.
+     *  - Alarms.
+     *  - Read only.
+     *  - Custom properties. X-KDE-KALARM- properties are interpreted and used to
+     *    set numerous KAEvent properties; non-KAlarm properties are simply stored.
+     *  - Custom status if equal to "DISABLED".
+     *  - Revision number.
+     */
     void set(const KCalCore::Event::Ptr &);
 
     KAEvent(const KAEvent &other);
@@ -363,7 +384,7 @@ public:
      *                        further changes have been applied to the instance;
      *                        call endChanges() when changes are complete.
      */
-    void set(const KDateTime &dt, const QString &text, const QColor &bg,
+    void set(const KADateTime &dt, const QString &text, const QColor &bg,
              const QColor &fg, const QFont &font, SubAction action, int lateCancel,
              Flags flags, bool changesPending = false);
 
@@ -725,11 +746,11 @@ public:
     /** Set the pre-alarm and post-alarm actions, and their options.
      *  @param pre  shell command to execute before the alarm is displayed
      *  @param post shell command to execute after the alarm is acknowledged
-     *  @param options options for pre- or post-alarm actions
+     *  @param preOptions options for pre-alarm actions
      *  @see preAction(), postAction(), extraActionOptions()
      *  @since 4.9
      */
-    void setActions(const QString &pre, const QString &post, ExtraActionOptions options);
+    void setActions(const QString &pre, const QString &post, ExtraActionOptions preOptions);
 
     /** Return the shell command to execute before the alarm is displayed. */
     QString preAction() const;
@@ -739,8 +760,8 @@ public:
      */
     QString postAction() const;
 
-    /** Return the pre- and post-alarm action options.
-     *  @see preAction(), postAction(), setActions()
+    /** Return the pre-alarm action options.
+     *  @see preAction(), setActions()
      *  @since 4.9
      */
     ExtraActionOptions extraActionOptions() const;
@@ -833,7 +854,8 @@ public:
     bool deferDefaultDateOnly() const;
 
     /** Return the start time for the event. If the event recurs, this is the
-     *  time of the first recurrence.
+     *  time of the first recurrence. If the event is date-only, this returns a
+     *  date-only value.
      *  @see mainDateTime()
      */
     DateTime startDateTime() const;
@@ -842,7 +864,7 @@ public:
      *  Note that for a recurring event, this should match one of the
      *  recurrence times.
      */
-    void setTime(const KDateTime &dt);
+    void setTime(const KADateTime &dt);
 
     /** Return the next time the main alarm will trigger.
      *  @param withRepeats  true to include sub-repetitions, false to exclude them.
@@ -883,12 +905,12 @@ public:
     /** Set the date/time the event was created, or saved in the archive calendar.
      *  @see createdDateTime()
      */
-    void setCreatedDateTime(const KDateTime &dt);
+    void setCreatedDateTime(const KADateTime &dt);
 
     /** Return the date/time the event was created, or saved in the archive calendar.
      *  @see setCreatedDateTime()
      */
-    KDateTime createdDateTime() const;
+    KADateTime createdDateTime() const;
 
     /** Enable or disable repeat-at-login.
      *  If @p repeat is true, any existing pre-alarm reminder, late-cancel and
@@ -913,6 +935,7 @@ public:
     void setExcludeHolidays(bool exclude);
 
     /** Return whether the alarm is disabled on holiday dates.
+     *  If no holiday region has been set by setHolidays(), this returns false;
      *  @see setExcludeHolidays()
      */
     bool holidaysExcluded() const;
@@ -943,7 +966,7 @@ public:
 
     /** Check whether a date/time is during working hours and/or holidays, depending
      *  on the flags set for the specified event. */
-    bool isWorkingTime(const KDateTime &dt) const;
+    bool isWorkingTime(const KADateTime &dt) const;
 
     /** Set working days and times, to be used by all KAEvent instances.
      *  @param days   bits set to 1 for each working day. Array element 0 = Monday ... 6 = Sunday.
@@ -972,7 +995,7 @@ public:
      *  @param end   = end date/time (set invalid to use @p count instead).
      *  @return @c false if no recurrence was set up.
      */
-    bool setRecurMinutely(int freq, int count, const KDateTime &end);
+    bool setRecurMinutely(int freq, int count, const KADateTime &end);
 
     /** Set the recurrence to recur daily.
      *  @param freq   how many days between recurrences.
@@ -1120,7 +1143,7 @@ public:
      *                            occur after @p preDateTime.
      *  @see nextOccurrence()
      */
-    bool occursAfter(const KDateTime &preDateTime, bool includeRepetitions) const;
+    bool occursAfter(const KADateTime &preDateTime, bool includeRepetitions) const;
 
     /** Set the date/time of the event to the next scheduled occurrence after a
      *  specified date/time, provided that this is later than its current date/time.
@@ -1130,7 +1153,7 @@ public:
      *  set as the next occurrence.
      *  @see nextOccurrence()
      */
-    OccurType setNextOccurrence(const KDateTime &preDateTime);
+    OccurType setNextOccurrence(const KADateTime &preDateTime);
 
     /** Get the date/time of the next occurrence of the event, after the specified
      *  date/time.
@@ -1138,7 +1161,7 @@ public:
      *  @param option  how/whether to make allowance for sub-repetitions.
      *  @see nextRepetition(), setNextOccurrence(), previousOccurrence(), occursAfter()
      */
-    OccurType nextOccurrence(const KDateTime &preDateTime, DateTime &result, OccurOption option = IGNORE_REPETITION) const;
+    OccurType nextOccurrence(const KADateTime &preDateTime, DateTime &result, OccurOption option = IGNORE_REPETITION) const;
 
     /** Get the date/time of the last previous occurrence of the event, before the
      *  specified date/time.
@@ -1149,7 +1172,7 @@ public:
      *                             appropriate.
      *  @see nextOccurrence()
      */
-    OccurType previousOccurrence(const KDateTime &afterDateTime, DateTime &result, bool includeRepetitions = false) const;
+    OccurType previousOccurrence(const KADateTime &afterDateTime, DateTime &result, bool includeRepetitions = false) const;
 
     /** Set the event to be a copy of the specified event, making the specified
      *  alarm the 'displaying' alarm.
@@ -1165,7 +1188,7 @@ public:
      *  @param showDefer  whether the Defer button was displayed
      *  @return @c true if successful, @c false if alarm was not copied.
      */
-    bool setDisplaying(const KAEvent &event, KAAlarm::Type type, Akonadi::Collection::Id colId, const KDateTime &repeatAtLoginTime, bool showEdit, bool showDefer);
+    bool setDisplaying(const KAEvent &event, KAAlarm::Type type, Akonadi::Collection::Id colId, const KADateTime &repeatAtLoginTime, bool showEdit, bool showDefer);
 
     /** Reinstate the original event from the 'displaying' event.
      *  This instance is initialised from the supplied displaying @p event,
@@ -1283,5 +1306,6 @@ private:
 Q_DECLARE_OPERATORS_FOR_FLAGS(KAlarmCal::KAEvent::Flags)
 Q_DECLARE_METATYPE(KAlarmCal::KAEvent)
 
-#endif // KAEVENT_H
+#endif // KALARM_KAEVENT_H
 
+// vim: et sw=4:
